Class: Labels::Image

Inherits:
Layer show all
Defined in:
lib/labels/image.rb

Overview

This class represents date layers.

Instance Attribute Summary collapse

Attributes inherited from Layer

#alpha, #column, #content, #height, #locked, #rotation, #title, #type, #visible, #width, #x, #y, #z

Method Summary

Methods inherited from Element

#initialize, #to_h

Constructor Details

This class inherits a constructor from Labels::Element

Instance Attribute Details

#fitObject

Whether or not to fit image to layer width and height



19
20
21
# File 'lib/labels/image.rb', line 19

def fit
  @fit
end

#stretchObject

Whether or not to stretch image to layer width and height



22
23
24
# File 'lib/labels/image.rb', line 22

def stretch
  @stretch
end