Class: Labels::Layer

Inherits:
Element show all
Defined in:
lib/labels/layer.rb

Overview

This class represents the base class for all layer types.

Direct Known Subclasses

Barcode, Image, Shape, Text

Instance Attribute Summary collapse

Method Summary

Methods inherited from Element

#initialize, #to_h

Constructor Details

This class inherits a constructor from Labels::Element

Instance Attribute Details

#alphaObject

Alpha (transparency) of layer



47
48
49
# File 'lib/labels/layer.rb', line 47

def alpha
  @alpha
end

#columnObject

Column from data set to use as replacement content



23
24
25
# File 'lib/labels/layer.rb', line 23

def column
  @column
end

#contentObject

Data content of layer



53
54
55
# File 'lib/labels/layer.rb', line 53

def content
  @content
end

#heightObject

Height of layer in pixels



44
45
46
# File 'lib/labels/layer.rb', line 44

def height
  @height
end

#lockedObject

Whether or not layer is locked



26
27
28
# File 'lib/labels/layer.rb', line 26

def locked
  @locked
end

#rotationObject

Rotation of layer in degrees



50
51
52
# File 'lib/labels/layer.rb', line 50

def rotation
  @rotation
end

#titleObject

Title of layer



17
18
19
# File 'lib/labels/layer.rb', line 17

def title
  @title
end

#typeObject

Type of layer



20
21
22
# File 'lib/labels/layer.rb', line 20

def type
  @type
end

#visibleObject

Whether or not layer is visible



29
30
31
# File 'lib/labels/layer.rb', line 29

def visible
  @visible
end

#widthObject

Width of layer in pixels



41
42
43
# File 'lib/labels/layer.rb', line 41

def width
  @width
end

#xObject

X position of layer in pixels



32
33
34
# File 'lib/labels/layer.rb', line 32

def x
  @x
end

#yObject

Y position of layer in pixels



35
36
37
# File 'lib/labels/layer.rb', line 35

def y
  @y
end

#zObject

Z position of layer in pixels



38
39
40
# File 'lib/labels/layer.rb', line 38

def z
  @z
end