Class: Labels::Image
Overview
This class represents date layers.
Instance Attribute Summary collapse
-
#fit ⇒ Object
Whether or not to fit image to layer width and height.
-
#stretch ⇒ Object
Whether or not to stretch image to layer width and height.
Attributes inherited from Layer
#alpha, #column, #content, #height, #locked, #rotation, #title, #type, #visible, #width, #x, #y, #z
Method Summary
Methods inherited from Element
Constructor Details
This class inherits a constructor from Labels::Element
Instance Attribute Details
#fit ⇒ Object
Whether or not to fit image to layer width and height
19 20 21 |
# File 'lib/labels/image.rb', line 19 def fit @fit end |
#stretch ⇒ Object
Whether or not to stretch image to layer width and height
22 23 24 |
# File 'lib/labels/image.rb', line 22 def stretch @stretch end |