Class: Labels::Layer
Overview
This class represents the base class for all layer types.
Instance Attribute Summary collapse
-
#alpha ⇒ Object
Alpha (transparency) of layer.
-
#column ⇒ Object
Column from data set to use as replacement content.
-
#content ⇒ Object
Data content of layer.
-
#height ⇒ Object
Height of layer in pixels.
-
#locked ⇒ Object
Whether or not layer is locked.
-
#rotation ⇒ Object
Rotation of layer in degrees.
-
#title ⇒ Object
Title of layer.
-
#type ⇒ Object
Type of layer.
-
#visible ⇒ Object
Whether or not layer is visible.
-
#width ⇒ Object
Width of layer in pixels.
-
#x ⇒ Object
X position of layer in pixels.
-
#y ⇒ Object
Y position of layer in pixels.
-
#z ⇒ Object
Z position of layer in pixels.
Method Summary
Methods inherited from Element
Constructor Details
This class inherits a constructor from Labels::Element
Instance Attribute Details
#alpha ⇒ Object
Alpha (transparency) of layer
47 48 49 |
# File 'lib/labels/layer.rb', line 47 def alpha @alpha end |
#column ⇒ Object
Column from data set to use as replacement content
23 24 25 |
# File 'lib/labels/layer.rb', line 23 def column @column end |
#content ⇒ Object
Data content of layer
53 54 55 |
# File 'lib/labels/layer.rb', line 53 def content @content end |
#height ⇒ Object
Height of layer in pixels
44 45 46 |
# File 'lib/labels/layer.rb', line 44 def height @height end |
#locked ⇒ Object
Whether or not layer is locked
26 27 28 |
# File 'lib/labels/layer.rb', line 26 def locked @locked end |
#rotation ⇒ Object
Rotation of layer in degrees
50 51 52 |
# File 'lib/labels/layer.rb', line 50 def rotation @rotation end |
#title ⇒ Object
Title of layer
17 18 19 |
# File 'lib/labels/layer.rb', line 17 def title @title end |
#type ⇒ Object
Type of layer
20 21 22 |
# File 'lib/labels/layer.rb', line 20 def type @type end |
#visible ⇒ Object
Whether or not layer is visible
29 30 31 |
# File 'lib/labels/layer.rb', line 29 def visible @visible end |
#width ⇒ Object
Width of layer in pixels
41 42 43 |
# File 'lib/labels/layer.rb', line 41 def width @width end |
#x ⇒ Object
X position of layer in pixels
32 33 34 |
# File 'lib/labels/layer.rb', line 32 def x @x end |
#y ⇒ Object
Y position of layer in pixels
35 36 37 |
# File 'lib/labels/layer.rb', line 35 def y @y end |
#z ⇒ Object
Z position of layer in pixels
38 39 40 |
# File 'lib/labels/layer.rb', line 38 def z @z end |